@@ -1,8 +1,8 @@
-#!/usr/bin/env python3
+#!/usr/bin/env python3/
 #
 # Author: Yipeng Sun
 # License: BSD 2-clause
-# Last Change: Wed Feb 16, 2022 at 12:53 PM -0500
+# Last Change: Fri Feb 18, 2022 at 05:36 PM -0500
 
 import numpy as np
 import matplotlib as mp
@@ -25,7 +25,7 @@ def filter_kwargs_func(kwargs, func):
     return kw_known, kw_rest
 
 
-def decorate_output(f, tight_layout=True, pad=0.):
+def decorate_output(f):
     @wraps(f)
     def wrapper(*args, **kwargs):
         result = f(*args, **kwargs)
@@ -36,8 +36,6 @@ def decorate_output(f, tight_layout=True, pad=0.):
             return data
 
         fig = data[0]
-        if tight_layout:
-            plt.tight_layout(pad=pad)
         fig.savefig(output)
         fig.clf()
         plt.close(fig)
@@ -75,8 +73,10 @@ def plot_prepare(figure=None, axis=None, title=None,
                  xlim=None, ylim=None,
                  xscale='linear', yscale='linear',
                  show_legend=True,
-                 legend_add_args={'numpoints': 1, 'loc': 'best'}):
+                 legend_add_args={'numpoints': 1, 'loc': 'best'},
+                 tight_layout={'pad': 0.0}):
     fig = plt.figure() if not figure else figure
+    fig.set_tight_layout(tight_layout)
 
     if not axis:
         ax = fig.add_subplot()
@@ -372,9 +372,10 @@ def plot_top_bot(top_plotters, bot_plotters,
                  ax1_yscale='linear', ax2_yscale='linear',
                  height_ratios=[3, 1],
                  legend_add_args={'numpoints': 1, 'loc': 'best'},
+                 tight_layout={'pad': 0.0},
                  **kwargs):
     fig = plt.figure()
-    fig.set_tight_layout({'pad': 0.})
+    fig.set_tight_layout(tight_layout)
 
     spec = fig.add_gridspec(ncols=1, nrows=2, height_ratios=height_ratios)
     spec.update(hspace=0.)
